ice_age
======
Freeze your ENVironment during testing. Just in case you need to change ENV variables during tests, this library ensures that everything is reset before the next test runs.


### Install
```pip install ice_age```


### Usage
```python
import ice_age

```

----
[![Build Status](https://travis-ci.org/dpep/py_ice_age.svg?branch=master)](https://travis-ci.org/dpep/py_rekey)
[![Coverage Status](https://coveralls.io/repos/github/dpep/py_ice_age/badge.svg?branch=master)](https://coveralls.io/github/dpep/py_ice_age?branch=master)
[![installs](https://img.shields.io/pypi/dm/ice_age.svg?label=installs)](https://pypi.org/project/ice_age)
